package SOCC::nagios_logwatchd::Config;

use 5.006001;
use strict;
use warnings;

require Exporter;
our @ISA = qw(Exporter);
our @EXPORT = qw(event_handler log_file ssh_host local_host);


# This package should be brought out of nagios_rrd before it
# goes into prod, djr.
use SOCC::nagios_rrd::Check;


sub event_handler ($) {
	return SOCC::nagios_logwatchd::Config::EventHandler->new($_[0]);
}



sub log_file ($) {
	return SOCC::nagios_logwatchd::Config::LogFile->new($_[0]);
}



{
	my @configs;
	
	sub ssh_host ($) {
		my $host = SOCC::nagios_logwatchd::Config::SshHost->new($_[0]);
		push(@configs, $host);
	}
	
	
	
	sub local_host ($) {
		my $host = SOCC::nagios_logwatchd::Config::LocalHost->new($_[0]);
		push(@configs, $host);
	}
	
	
	
	sub get_configs {
		return \@configs;
	}
}


#--------------------------------------------------------------------------
package SOCC::nagios_logwatchd::Config::Common;
use Carp;
use SOCC::nagios_rrd::Check;
our @CARP_NOT = ('SOCC::nagios_logwatchd::Config');


sub new { die "abstract method" };


sub AUTOLOAD {
	my ($self) = @_;
	
	our $AUTOLOAD;
	my $attribute = $AUTOLOAD;
	$attribute =~ s/^ .+ :: //x;
	
	return $self->{$attribute};
}

#--------------------------------------------------------------------------
package SOCC::nagios_logwatchd::Config::EventHandler;
use Carp;
use SOCC::nagios_rrd::Check;
our @ISA = ('SOCC::nagios_logwatchd::Config::Common');

sub new {
	my ($class, $config) = @_;
	
	my $error = check($config,
		stop => '&?',
		line => '&',
		start => '&?');
	croak $error if $error;
	
	return bless($config, $class);
}

#--------------------------------------------------------------------------
package SOCC::nagios_logwatchd::Config::LogFile;
use Carp;
use SOCC::nagios_rrd::Check;
our @ISA = ('SOCC::nagios_logwatchd::Config::Common');

sub new {
	my ($class, $config) = @_;
	
	my $error = check($config,
		path => '$',
		event_handler => 'SOCC::nagios_logwatchd::Config::EventHandler');
	croak $error if $error;
	
	return bless($config, $class);
}

#--------------------------------------------------------------------------
package SOCC::nagios_logwatchd::Config::SshHost;
use Carp;
use SOCC::nagios_rrd::Check;
our @ISA = ('SOCC::nagios_logwatchd::Config::Hosts');

sub new {
	my ($class, $config) = @_;
	
	my $error = check($config,
		host_name => '$',
		ip_address => '$?',
		user => '$?',
		logs => '@');
	$error = check($config->{logs}, min => 1,
		isa => 'SOCC::nagios_logwatchd::Config::LogFile') unless defined $error;
	croak $error if $error;
	
	return bless($config, $class);
}

#--------------------------------------------------------------------------
package SOCC::nagios_logwatchd::Config::LocalHost;
use Carp;
use SOCC::nagios_rrd::Check;
our @ISA = ('SOCC::nagios_logwatchd::Config::Hosts');

sub new {
	my ($class, $config) = @_;
	
	my $error = check($config,
		host_name => '$',
		logs => '@');
	$error = check($config->{logs}, min => 1,
		isa => 'SOCC::nagios_logwatchd::Config::LogFile') unless defined $error;
	croak $error if $error;
	
	return bless($config, $class);
}

#--------------------------------------------------------------------------
package SOCC::nagios_logwatchd::Config::Hosts;
use Carp;
use SOCC::nagios_rrd::Check;
our @ISA = ('SOCC::nagios_logwatchd::Config::Common');


sub new { die "abstract method" };


#--------------------------------------------------------------------------
1;

