package SOCC::nagios_logwatchd::TimeHandlers;

use strict;
use warnings;
use English;

use fields qw(_handlers _min_time_t);



sub new {
	my ($class) = @_;
	
	my $self = fields::new($class);
	$self->{_handlers} = {};
	
	return $self;
}



use Class::Struct 'SOCC::nagios_rrd::TimeHandlers::_Handler' =>
	{time_t => '$', id => '$', sub_ref => '$', args => '@'};

sub add {
	my ($self, $time_t, $id, $sub_ref, @args) = @_;
	
	$self->{_handlers}->{$id} = SOCC::nagios_rrd::TimeHandlers::_Handler->new(
		time_t => $time_t,
		id => $id,
		sub_ref => $sub_ref,
		args => \@args);
	
	if (! defined $self->{_min_time_t} || $time_t < $self->{_min_time_t}) {
		$self->{_min_time_t} = $time_t;
	}
}



sub check {
	my ($self, $time_t) = @_;
	
	my @ordered_time_handlers = sort({$a->time_t <=> $b->time_t}
		values(%{$self->{_handlers}}));
	for my $th (@ordered_time_handlers) {
		if ($th->time_t <= $time_t) {
			delete $self->{_handlers}->{$th->id};
			&{$th->sub_ref}($self, $th->id, @{$th->args});
		} else {
			$self->{_min_time_t} = $th->time_t;
			last;
		}
	}
}



sub secs_left {
	my ($self, $time_t) = @_;
	
	my $secs_left = $self->{_min_time_t} - $time_t;
	if ($secs_left < 0) {
		$secs_left = 0;
	}
	
	return $secs_left;
}

#--------------------------------------------------------------------------

1;

